==> rat2302.db_2.0.2.tar.gz: rat2302.db/man/rat2302_dbconn.Rd <==
\name{rat2302_dbconn}

\alias{rat2302_dbconn}
\alias{rat2302_dbfile}
\alias{rat2302_dbschema}
\alias{rat2302_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  rat2302_dbconn()
  rat2302_dbfile()
  rat2302_dbschema(file="", show.indices=FALSE)
  rat2302_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{rat2302_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{rat2302_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{rat2302_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{rat2302_dbschema} prints the schema definition of the
  package annotation DB.

  \code{rat2302_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{rat2302_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{rat2302_dbfile}: a character string with the path to the
  package annotation DB.

  \code{rat2302_dbschema}: none (invisible \code{NULL}).

  \code{rat2302_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(rat2302_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by rat2302_dbconn() was created with:
  dbConnect(SQLite(), dbname=rat2302_dbfile(), cache_size=64000, synchronous=0)

  rat2302_dbschema()

  rat2302_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> rat2302.db_2.7.1.tar.gz: rat2302.db/man/rat2302_dbconn.Rd <==

\name{rat2302_dbconn}

\alias{rat2302_dbconn}
\alias{rat2302_dbfile}
\alias{rat2302_dbschema}
\alias{rat2302_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  rat2302_dbconn()
  rat2302_dbfile()
  rat2302_dbschema(file="", show.indices=FALSE)
  rat2302_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{rat2302_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{rat2302_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{rat2302_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{rat2302_dbschema} prints the schema definition of the
  package annotation DB.

  \code{rat2302_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{rat2302_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{rat2302_dbfile}: a character string with the path to the
  package annotation DB.

  \code{rat2302_dbschema}: none (invisible \code{NULL}).

  \code{rat2302_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(rat2302_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by rat2302_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=rat2302_dbfile(), cache_size=64000,
  synchronous=0)

  rat2302_dbschema()

  rat2302_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
